==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/OneCFAContextManager.h <==
// public class soot.jimple.toolkits.callgraph.OneCFAContextManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3a83ceb12d30ce09 soot_jimple_toolkits_callgraph_OneCFAContextManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_OneCFAContextManager_H_
#define _JC_soot_jimple_toolkits_callgraph_OneCFAContextManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodOrMethodContext$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_refs	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$refs	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$nonrefs	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vmethods	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtable	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method$_init$df901ac5be0f618e(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method$addStaticEdge$706703d22e71fdf2(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, jint);
extern void _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method$addVirtualEdge$8ec9a4a06ee6b271(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, jint, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method$callGraph$5bc8d49f2f0918d1(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method_info$addStaticEdge$706703d22e71fdf2;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method_info$addVirtualEdge$8ec9a4a06ee6b271;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method_info$callGraph$5bc8d49f2f0918d1;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vmethods {
	void	(*addStaticEdge$706703d22e71fdf2)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, jint);
	void	(*addVirtualEdge$8ec9a4a06ee6b271)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, jint, struct _jc_java_lang_Object$object *);
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*(*callGraph$5bc8d49f2f0918d1)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vmethods	soot_jimple_toolkits_callgraph_OneCFAContextManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$refs {
    _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_refs	soot_jimple_toolkits_callgraph_OneCFAContextManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_nonrefs	soot_jimple_toolkits_callgraph_OneCFAContextManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object {
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_OneCFAContextManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_OneCFAContextManager_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/OneCFAContextManager.h <==
// public class soot.jimple.toolkits.callgraph.OneCFAContextManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3a83ceb12d30ce09 soot_jimple_toolkits_callgraph_OneCFAContextManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_OneCFAContextManager_H_
#define _JC_soot_jimple_toolkits_callgraph_OneCFAContextManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodOrMethodContext$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_refs	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$refs	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$nonrefs	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vmethods	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtable	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method$_init$df901ac5be0f618e(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method$addStaticEdge$706703d22e71fdf2(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method$addVirtualEdge$8ec9a4a06ee6b271(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method$callGraph$5bc8d49f2f0918d1(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method_info$addStaticEdge$706703d22e71fdf2;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method_info$addVirtualEdge$8ec9a4a06ee6b271;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$method_info$callGraph$5bc8d49f2f0918d1;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vmethods {
	void	(*addStaticEdge$706703d22e71fdf2)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, jint) _JC_JCNI_ATTR;
	void	(*addVirtualEdge$8ec9a4a06ee6b271)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*(*callGraph$5bc8d49f2f0918d1)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vmethods	soot_jimple_toolkits_callgraph_OneCFAContextManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$refs {
    _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_refs	soot_jimple_toolkits_callgraph_OneCFAContextManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$sub_nonrefs	soot_jimple_toolkits_callgraph_OneCFAContextManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$object {
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$vtype _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_OneCFAContextManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_OneCFAContextManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_OneCFAContextManager_H_ */
